@@ -5,7 +5,7 @@ from ruamel import yaml
 
 from qhub.destroy import destroy_configuration
 from qhub.schema import verify
-from qhub.render import render_default_template, render_template
+from qhub.render import render_template
 
 logger = logging.getLogger(__name__)
 
@@ -13,7 +13,6 @@ logger = logging.getLogger(__name__)
 def create_destroy_subcommand(subparser):
     subparser = subparser.add_parser("destroy")
     subparser.add_argument("-c", "--config", help="qhub configuration", required=True)
-    subparser.add_argument("-i", "--input", help="input directory")
     subparser.add_argument("-o", "--output", default="./", help="output directory")
     subparser.add_argument(
         "--skip-remote-state-provision",
@@ -41,10 +40,7 @@ def handle_destroy(args):
     verify(config)
 
     if not args.disable_render:
-        if args.input is None:
-            render_default_template(args.output, args.config, force=True)
-        else:
-            render_template(args.input, args.output, args.config, force=True)
+        render_template(args.output, args.config, force=True)
 
     destroy_configuration(
         config,
