@@ -1,4 +1,5 @@
 import logging
+import os
 import re
 from subprocess import CalledProcessError
 
@@ -42,6 +43,9 @@ def guided_install(
 ):
     # 01 Check Environment Variables
     check_cloud_credentials(config)
+    # Check that secrets required for terraform
+    # variables are set as required
+    check_secrets(config)
 
     # 02 Create terraform backend remote state bucket
     # backwards compatible with `qhub-config.yaml` which
@@ -97,10 +101,12 @@ def guided_install(
         zone_name = ".".join(zone_name)
         if config["provider"] in {"do", "gcp", "azure"}:
             update_record(zone_name, record_name, "A", ip_or_hostname)
-            add_clearml_dns(zone_name, record_name, "A", ip_or_hostname)
+            if config.get("clearml", {}).get("enabled"):
+                add_clearml_dns(zone_name, record_name, "A", ip_or_hostname)
         elif config["provider"] == "aws":
             update_record(zone_name, record_name, "CNAME", ip_or_hostname)
-            add_clearml_dns(zone_name, record_name, "CNAME", ip_or_hostname)
+            if config.get("clearml", {}).get("enabled"):
+                add_clearml_dns(zone_name, record_name, "CNAME", ip_or_hostname)
         else:
             logger.info(
                 f"Couldn't update the DNS record for cloud provider: {config['provider']}"
@@ -125,3 +131,29 @@ def add_clearml_dns(zone_name, record_name, record_type, ip_or_hostname):
 
     for dns_record in dns_records:
         update_record(zone_name, dns_record, record_type, ip_or_hostname)
+
+
+def check_secrets(config):
+    """
+    Checks that the appropriate variables are set based on the current config.
+    These variables are prefixed with TF_VAR_ and are used to populate the
+    corresponding variables in the terraform deployment. e.g.
+    TF_VAR_prefect_token sets the prefect_token variable in Terraform. These
+    values are set in the terraform state but are not leaked when the
+    terraform render occurs.
+    """
+
+    missing_env_vars = []
+
+    # Check prefect integration set up.
+    if "prefect" in config and config["prefect"]["enabled"]:
+        var = "TF_VAR_prefect_token"
+        if var not in os.environ:
+            missing_env_vars.append(var)
+
+    if missing_env_vars:
+        raise EnvironmentError(
+            "Some environment variables used to propagate secrets to the "
+            "terraform deployment were not set. Please set these before "
+            f"continuing: {', '.join(missing_env_vars)}"
+        )
