@@ -1,9 +1,9 @@
 import pathlib
 import collections
+import functools
 import json
 import os
-from shutil import copyfile
-from gitignore_parser import parse_gitignore
+from shutil import rmtree
 
 from ruamel import yaml
 from cookiecutter.generate import generate_files
@@ -20,9 +20,10 @@ def patch_dask_gateway_extra_config(config):
     directory.
 
     """
+    namespace = config["namespace"]
     conda_store_volume = {
         "name": "conda-store",
-        "persistentVolumeClaim": {"claimName": "conda-store-dev-share"},
+        "persistentVolumeClaim": {"claimName": f"conda-store-{namespace}-share"},
     }
     extra_pod_config = {"volumes": [conda_store_volume]}
 
@@ -115,6 +116,12 @@ def render_template(output_directory, config_filename, force=False):
 
     with filename.open() as f:
         config = yaml.safe_load(f)
+
+        # For any config values that start with
+        # QHUB_SECRET_, set the values using the
+        # corresponding env var.
+        set_env_vars_in_config(config)
+
         config["repo_directory"] = repo_directory
         patch_dask_gateway_extra_config(config)
 
@@ -124,8 +131,8 @@ def render_template(output_directory, config_filename, force=False):
     patch_versioning_extra_config(config)
 
     remove_existing_renders(
-        source_repo_dir=input_directory / "{{ cookiecutter.repo_directory }}",
         dest_repo_dir=output_directory / repo_directory,
+        verbosity=2,
     )
 
     generate_files(
@@ -136,57 +143,94 @@ def render_template(output_directory, config_filename, force=False):
     )
 
 
-def remove_existing_renders(source_repo_dir, dest_repo_dir):
+def remove_existing_renders(dest_repo_dir, verbosity=0):
     """
-    Remove existing folder structure in output_dir apart from:
-    Files matching gitignore entries from the source template
-    Anything the user has added to a .qhubignore file in the output_dir (maybe their own github workflows)
-
-    No FILES in the dest_repo_dir are deleted.
-
-    The .git folder remains intact
+    Remove all files and directories beneath each directory in `deletable_dirs`. These files and directories will be regenerated in the next step (`generate_files`) based on the configurations set in `qhub-config.yml`.
 
     Inputs must be pathlib.Path
     """
-    copyfile(str(source_repo_dir / ".gitignore"), str(dest_repo_dir / ".gitignore"))
+    home_dir = pathlib.Path.home()
+    if pathlib.Path.cwd() == home_dir:
+        raise ValueError(
+            f"Deploying QHub from the home directory, {home_dir}, is not permitted."
+        )
 
-    gitignore_matches = parse_gitignore(dest_repo_dir / ".gitignore")
+    deletable_dirs = [
+        "terraform-state",
+        ".github",
+        "infrastructure",
+        "image",
+        ".gitlab-ci.yml",
+    ]
 
-    if (dest_repo_dir / ".qhubignore").is_file():
-        qhubignore_matches = parse_gitignore(dest_repo_dir / ".qhubignore")
+    for deletable_dir in deletable_dirs:
+        deletable_dir = dest_repo_dir / deletable_dir
+        if deletable_dir.exists():
+            if verbosity > 0:
+                print(f"Deleting all files and directories beneath {deletable_dir} ...")
+            rmtree(deletable_dir)
+
+
+def set_env_vars_in_config(config):
+    """
+
+    For values in the config starting with 'QHUB_SECRET_XXX' the environment
+    variables are searched for the pattern XXX and the config value is
+    modified. This enables setting secret values that should not be directly
+    stored in the config file.
+
+    NOTE: variables are most likely written to a file somewhere upon render. In
+    order to further reduce risk of exposure of any of these variables you might
+    consider preventing storage of the terraform render output.
+    """
+    private_entries = get_secret_config_entries(config)
+    for idx in private_entries:
+        set_qhub_secret(config, idx)
+
+
+def get_secret_config_entries(config, config_idx=None, private_entries=None):
+    output = private_entries or []
+    if config_idx is None:
+        sub_dict = config
+        config_idx = []
     else:
+        sub_dict = get_sub_config(config, config_idx)
 
-        def qhubignore_matches(_):
-            return False  # Dummy blank qhubignore
+    for key, value in sub_dict.items():
+        if type(value) is dict:
+            sub_dict_outputs = get_secret_config_entries(
+                config, [*config_idx, key], private_entries
+            )
+            output = [*output, *sub_dict_outputs]
+        else:
+            if "QHUB_SECRET_" in str(value):
+                output = [*output, [*config_idx, key]]
+    return output
 
-    for root, dirs, files in os.walk(dest_repo_dir, topdown=False):
-        if (
-            root.startswith(f"{str(dest_repo_dir)}/.git/")
-            or root == f"{str(dest_repo_dir)}/.git"
-        ):
-            # Leave everything in the .git folder
-            continue
 
-        root_path = pathlib.Path(root)
+def get_sub_config(conf, conf_idx):
+    sub_config = functools.reduce(dict.__getitem__, conf_idx, conf)
+    return sub_config
 
-        if root != str(
-            dest_repo_dir
-        ):  # Do not delete top-level files such as qhub-config.yaml!
-            for file in files:
 
-                if not gitignore_matches(root_path / file) and not qhubignore_matches(
-                    root_path / file
-                ):
+def set_sub_config(conf, conf_idx, value):
 
-                    os.remove(root_path / file)
+    get_sub_config(conf, conf_idx[:-1])[conf_idx[-1]] = value
 
-        for dir in dirs:
-            if (
-                not gitignore_matches(root_path / dir)
-                and not (dir == ".git" and root_path == dest_repo_dir)
-                and not qhubignore_matches(root_path / dir)
-            ):
-                try:
-                    os.rmdir(root_path / dir)
-                except OSError:
-                    pass  # Silently fail if 'saved' files are present so dir not empty
+
+def set_qhub_secret(config, idx):
+    placeholder = get_sub_config(config, idx)
+    secret_var = get_qhub_secret(placeholder)
+    set_sub_config(config, idx, secret_var)
+
+
+def get_qhub_secret(secret_var):
+    env_var = secret_var.lstrip("QHUB_SECRET_")
+    val = os.environ.get(env_var)
+    if not val:
+        raise EnvironmentError(
+            f"Since '{secret_var}' was found in the"
+            " QHub config, the environment variable"
+            f" '{env_var}' must be set."
+        )
+    return val
