@@ -4,6 +4,7 @@ import time
 import os
 import re
 import contextlib
+from typing import Sequence, Set
 
 from .version import __version__
 
@@ -97,7 +98,6 @@ def check_cloud_credentials(config):
         for variable in {
             "AWS_ACCESS_KEY_ID",
             "AWS_SECRET_ACCESS_KEY",
-            "AWS_DEFAULT_REGION",
         }:
             if variable not in os.environ:
                 raise ValueError(
@@ -136,3 +136,13 @@ def check_cloud_credentials(config):
         pass
     else:
         raise ValueError("Cloud Provider configuration not supported")
+
+
+def check_for_duplicates(users: Sequence[dict]) -> Set:
+    uids = set([])
+    for user, attrs in users.items():
+        if attrs["uid"] in uids:
+            raise TypeError(f"Found duplicate uid ({attrs['uid']}) for {user}.")
+        else:
+            uids.add(attrs["uid"])
+    return users
